### Cloudformation

N.B. This gem solves very specific and limited use cases, and is in no way exhaustive (although it may be easily monkey patched to add in additional functions)

#### Create a cloudformation stack from a public template url

```
  aws_clients = ::AwsClient::Container.new(ORG_KEY, AWS_REGION, PROVISIONING_REGION)

  cloudformation_client = aws_clients.cloudformation

  cloudformation_client.create_stack(
    stack_name:  "The name for you stack",
    template_url: "The URL at which your cloudformation template can be found (in S3)"
    capabilities: ["List", "of", "capabilities"] # e.g ["CAPABILITY_IAM"],
    on_failure: "failure action" # e.g. "DO_NOTHING" | "ROLLBACK" | "DELETE"
    tags = [
      { key: "value" }, 
      { secondkey: "secondvalue" }
    ]  
  )
```

#### Update an existing stack

```
  aws_clients = ::AwsClient::Container.new(ORG_KEY, AWS_REGION, PROVISIONING_REGION)

  cloudformation_client = aws_clients.cloudformation

  cloudformation_client.update_stack(

    ...
      stack parameters
    ...

  )

```

For stack parameter options, see: http://docs.aws.amazon.com/sdkforruby/api/Aws/CloudFormation/Client.html#update_stack-instance_method

#### Get stack status

```
  cloudformation_client.stack_status("STACK NAME")
```


#### Accessing the underlying client

```
  aws_clients = ::AwsClient::Container.new(ORG_KEY, AWS_REGION, PROVISIONING_REGION)
  cloudformation_client = aws_clients.cloudformation
  underlying_client = cloudformation_client.client
```

#### Extending functionality with a patch:

Extend the following class:

```
  module AwsClient
    class CfWrapper < AwsClient::Wrapper

      ...
    
    end
  end
```

See 'Accessing the underlying client', above, for how to access the underlying cloudformation client.

